==> ng-drupal-7-services-2.2.4.tgz: package/docs/js/docs-setup.js <==
NG_DOCS={
  "sections": {
    "api": "API Documentation"
  },
  "pages": [
    {
      "section": "api",
      "id": "d7-services.commons.authentication:Authentication",
      "shortName": "Authentication",
      "type": "object",
      "moduleName": "d7-services.commons",
      "shortDescription": "This module bundles all modules related to drupal authentication resource",
      "keywords": "api authentication bundles channel channelconstant commons d7-services drupal httpintercepter module modules object resource service serviceconstant"
    },
    {
      "section": "api",
      "id": "d7-services.commons.baseChannel:BaseChannel",
      "shortName": "BaseChannel",
      "type": "service",
      "moduleName": "d7-services.commons",
      "shortDescription": "An abstract notification channel.",
      "keywords": "$emit $mapargs $rootscope $scope $scopes _scope abstract angular angularjs api args arguments basechannel call callback calls changes channel channels commons config controller customize d7-services data defined directive efficient enables event eventname events fast function handler http mapper method module my_event mymodule notification publish published pubrootemit scope scopehandler service subrootemit subscriba subscribe unsubscribe unsubscribehandler var"
    },
    {
      "section": "api",
      "id": "d7-services.commons.directives:Directives",
      "shortName": "Directives",
      "type": "object",
      "moduleName": "d7-services.commons",
      "shortDescription": "This module bundles all modules related to the commons directives",
      "keywords": "api bundles commons d7-services directives module modules object togglebyaccesslevel"
    },
    {
      "section": "api",
      "id": "d7-services.commons.http:Http",
      "shortName": "Http",
      "type": "object",
      "moduleName": "d7-services.commons",
      "shortDescription": "This module bundles all modules related to drupal comment resource",
      "keywords": "api bundles comment commons configurations d7-services drupal http intercepter module modules object requestaccept resource"
    },
    {
      "section": "api",
      "id": "d7-services.commons:Commons",
      "shortName": "Commons",
      "type": "object",
      "moduleName": "d7-services",
      "shortDescription": "This module bundles all modules related to the commons modules",
      "keywords": "api authentication basechannel baseresource bundles commons configurations d7-services directives helperservice http module modules object validationconstant"
    },
    {
      "section": "api",
      "id": "d7-services.resources.comment:Comment",
      "shortName": "Comment",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This module bundles all modules related to drupal comment resource",
      "keywords": "api bundles channel channelconstant comment d7-services drupal module modules object resource resourceconstant resources"
    },
    {
      "section": "api",
      "id": "d7-services.resources.definition:Definition",
      "shortName": "Definition",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This module bundles all modules related to drupal definition resource",
      "keywords": "api bundles channel channelconstant d7-services definition drupal module modules object resource resourceconstant resources"
    },
    {
      "section": "api",
      "id": "d7-services.resources.file:File",
      "shortName": "File",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This module bundles all modules related to drupal file resource",
      "keywords": "api bundles channel channelconstant d7-services drupal file module modules object resource resourceconstant resources"
    },
    {
      "section": "api",
      "id": "d7-services.resources.geocoder:Geocoder",
      "shortName": "Geocoder",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This module bundles all modules related to drupal geocoder resource",
      "keywords": "api bundles channel channelconstant d7-services drupal geocoder module modules object resource resourceconstant resources"
    },
    {
      "section": "api",
      "id": "d7-services.resources.menu:Menu",
      "shortName": "Menu",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This module bundles all modules related to drupal menu resource",
      "keywords": "api bundles channel channelconstant d7-services drupal menu module modules object resource resourceconstant resources"
    },
    {
      "section": "api",
      "id": "d7-services.resources.node:Node",
      "shortName": "Node",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This Module bundles all modules related to drupal node resource",
      "keywords": "api bundles channel channelconstant d7-services drupal module modules node object resource resourceconstant resources"
    },
    {
      "section": "api",
      "id": "d7-services.resources.system.channel:SystemChannel",
      "shortName": "SystemChannel",
      "type": "service",
      "moduleName": "d7-services.resources.system",
      "shortDescription": "Notification channel for system resource.",
      "keywords": "$rootscope _scope angular api args arguments automatically basechannel call callback channel channelconstant commons confirm connectconfirmed connectfailed controller d7-services data delvariableconfirmed delvariablefailed destroy event eventbus events failed function getvariableconfirmed getvariablefailed method module mycontroller mymodule notification os pubconnectconfirmed pubconnectfailed pubgetvariableconfirmed publish request requests resource resources scope scopehandler scopes service setvariableconfirmed setvariablefailed specific subconnectconfirmed subconnectfailed subdelvariableconfirmed subdelvariablefailed subgetvariableconfirmed subgetvariablefailed subscribe subscribes subsetvariableconfirmed subsetvariablefailed system systemchannel systemconnectconfirmed systemresource systemresources unsub unsubscribe unsubscribes var"
    },
    {
      "section": "api",
      "id": "d7-services.resources.system.channelConstant:SystemChannelConstant",
      "shortName": "SystemChannelConstant",
      "type": "object",
      "moduleName": "d7-services.resources.system",
      "shortDescription": "Constant for the System channel",
      "keywords": "angular api channel channelconstant class config confirm connect connectconfirmed connectfailed console constant controller d7-services d7-services-resources-system-channelconstant-page d7-services-resources-system-channelconstant-systemchannelconstant-page delvariable delvariableconfirmed delvariablefailed editable event failed getvariable getvariableconfirmed getvariablefailed injectable log module my_event_name mymodule object phase resources setvariable setvariableconfirmed setvariablefailed system systemchannelconstant"
    },
    {
      "section": "api",
      "id": "d7-services.resources.system.resource:SystemResource",
      "shortName": "SystemResource",
      "type": "service",
      "moduleName": "d7-services.resources.system",
      "shortDescription": "This service mirrors the Drupal system resource of the services 3.x module.",
      "keywords": "_default angular api avoid baseresource body callback care case case-sensitivity channelconstant collation commons config configurations confirm connect cors currently d7-services data database default del_variable depends details drupal event fail false function functions get_variable handling http logged lower method mirrors module mymodule names object performing persistent php post problems promise request requests required resource resourceconstant resources return returns serialization service services session set set_variable sets settings source subconnectconfirm successful system systemchannel systemresource true type undefine unsets url user variable variable_"
    },
    {
      "section": "api",
      "id": "d7-services.resources.system.resourceConstant:SystemResourceConstant",
      "shortName": "SystemResourceConstant",
      "type": "object",
      "moduleName": "d7-services.resources.system",
      "shortDescription": "Constant for the System resource",
      "keywords": "actions alias alisa angular api class config connect console constant controller custom d7-services d7-services-resources-system-resourceconstant-page d7-services-resources-system-resourceconstant-systemresourceconstant-page default del_variable drupal editable get_variable injectable log module mymodule object override path phase property provided resource resourceconstant resourcepath resources set subpaths system systemresourceconstant"
    },
    {
      "section": "api",
      "id": "d7-services.resources.system:System",
      "shortName": "System",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This Module bundles all modules related to drupal system resource",
      "keywords": "api bundles channel channelconstant d7-services drupal module modules object resource resourceconstant resources system"
    },
    {
      "section": "api",
      "id": "d7-services.resources.taxonomy_term:TaxonomyTerm",
      "shortName": "TaxonomyTerm",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This Module bundles all modules related to drupal taxonomy_term resource",
      "keywords": "api bundles channel channelconstant d7-services drupal module modules object resource resourceconstant resources taxonomy_term"
    },
    {
      "section": "api",
      "id": "d7-services.resources.taxonomy_vocabulary:TaxonomyVocabulary",
      "shortName": "TaxonomyVocabulary",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This Module bundles all modules related to drupal taxonomy_vocabulary resource",
      "keywords": "api bundles channel channelconstant d7-services drupal module modules object resource resourceconstant resources taxonomy_vocabulary"
    },
    {
      "section": "api",
      "id": "d7-services.resources.user:User",
      "shortName": "User",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This Module bundles all modules related to drupal user resource",
      "keywords": "api bundles channel channelconstant d7-services drupal module modules object resource resourceconstant resources user"
    },
    {
      "section": "api",
      "id": "d7-services.resources.views:Views",
      "shortName": "Views",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This Module bundles all modules related to drupal views resource",
      "keywords": "api bundles channel channelconstant d7-services drupal module modules object operatorsconstant resource resourceconstant resources views"
    },
    {
      "section": "api",
      "id": "d7-services.resources:Resources",
      "shortName": "Resources",
      "type": "object",
      "moduleName": "d7-services",
      "shortDescription": "This Module bundles all modules related to drupals resources",
      "keywords": "api bundle bundles comment d7-services definition drupals file geocoder menu module modules node object resources system taxonomy_term taxonomy_vocabulary user views"
    },
    {
      "section": "api",
      "id": "d7-services:D7Services",
      "shortName": "D7Services",
      "type": "object",
      "moduleName": "d7-services:D7Services",
      "shortDescription": "This Module bundles all ng-drupal-7-services modules",
      "keywords": "api bundle bundles commons d7-services module modules ng-drupal-7-services object resources"
    }
  ],
  "apis": {
    "api": true
  },
  "__file": "_FAKE_DEST_/js/docs-setup.js",
  "__options": {
    "startPage": "/api",
    "scripts": [
      "js/angular.min.js",
      "js/angular-animate.min.js",
      "js/marked.js"
    ],
    "styles": [],
    "title": "API Documentation",
    "html5Mode": true,
    "editExample": true,
    "navTemplate": false,
    "navContent": "",
    "navTemplateData": {},
    "loadDefaults": {
      "angular": true,
      "angularAnimate": true,
      "marked": true
    }
  },
  "html5Mode": true,
  "editExample": true,
  "startPage": "/api",
  "scripts": [
    "js/angular.min.js",
    "js/angular-animate.min.js",
    "js/marked.js"
  ]
};

==> ng-drupal-7-services-2.2.6.tgz: package/docs/js/docs-setup.js <==
NG_DOCS={
  "sections": {
    "api": "API Documentation"
  },
  "pages": [
    {
      "section": "api",
      "id": "d7-services.commons.authentication:Authentication",
      "shortName": "Authentication",
      "type": "object",
      "moduleName": "d7-services.commons",
      "shortDescription": "This module bundles all modules related to drupal authentication resource",
      "keywords": "api authentication bundles channel channelconstant commons d7-services drupal httpintercepter module modules object resource service serviceconstant"
    },
    {
      "section": "api",
      "id": "d7-services.commons.baseChannel:BaseChannel",
      "shortName": "BaseChannel",
      "type": "service",
      "moduleName": "d7-services.commons",
      "shortDescription": "An abstract notification channel.",
      "keywords": "$emit $rootscope $scope $scopes _scope abstract angular angularjs api args arguments basechannel call callback calls changes channel channels commons controller customize d7-services data defined directive efficient enables event eventname events fast function handler http mapargs mapper method module my_event mycontroller mymodule notification publish published pubrootemit scope scopehandler service subrootemit subscriba subscribe unsubscribe unsubscribehandler var"
    },
    {
      "section": "api",
      "id": "d7-services.commons.baseResource:BaseResource",
      "shortName": "BaseResource",
      "type": "service",
      "moduleName": "d7-services.commons",
      "shortDescription": "An abstract resource providing retrieve, create, update, delete and index functions.",
      "keywords": "abstract angular api baseresource basic commons configurations controller create createpath d7-services data delete deletepath depending drupals emits empty entries error event events fields format formata formated formats function functions generic handle http indexpath json key method module mycontroller mymodule number operations options output pagenumber pagesize param parameters params path preparegetparam prepareindexgetparams preparepostdata prepares promise providing puberror publish pubsuccess pust request requestconfig requests resource resources retrieve retrievepath search service start string subscriba success update updatepath url values var"
    },
    {
      "section": "api",
      "id": "d7-services.commons.configurations:DrupalApiConstant",
      "shortName": "DrupalApiConstant",
      "type": "object",
      "moduleName": "d7-services.commons",
      "shortDescription": "Constant for the d7-services module. Holds general options, request relevant data, defaults, filter options, imagestyles and so on.",
      "keywords": "angular api api_endpoint class commons config configurations configured constant d7-services d7-services-commons-configurations-drupalapiconstant-page d7-services-commons-configurations-page data day default defaults domain drupal drupal_instance drupalapiconstant drupals editable expiration expriation filter folder format formatters general holds hr href https image imagestyles language language_none large lifetime medium min module mxcustomstyle my_custom_style mymodule object options org parsing path phase private privatefilepath public publicfilepath relevant request response responseformat seconds services session session_expiration_time session_expiration_unite sessions sites style styles thumbnail time untis"
    },
    {
      "section": "api",
      "id": "d7-services.commons.directives:Directives",
      "shortName": "Directives",
      "type": "object",
      "moduleName": "d7-services.commons",
      "shortDescription": "This module bundles all modules related to the commons directives",
      "keywords": "api bundles commons d7-services directives module modules object togglebyaccesslevel"
    },
    {
      "section": "api",
      "id": "d7-services.commons.http:Http",
      "shortName": "Http",
      "type": "object",
      "moduleName": "d7-services.commons",
      "shortDescription": "This module bundles all modules related to drupal comment resource",
      "keywords": "api bundles comment commons configurations d7-services drupal http intercepter module modules object requestaccept resource"
    },
    {
      "section": "api",
      "id": "d7-services.commons:Commons",
      "shortName": "Commons",
      "type": "object",
      "moduleName": "d7-services",
      "shortDescription": "This module bundles all modules related to the commons modules",
      "keywords": "api authentication basechannel baseresource bundles commons configurations d7-services directives helperservice http module modules object validationconstant"
    },
    {
      "section": "api",
      "id": "d7-services.resources.comment:Comment",
      "shortName": "Comment",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This module bundles all modules related to drupal comment resource",
      "keywords": "api bundles channel channelconstant comment d7-services drupal module modules object resource resourceconstant resources"
    },
    {
      "section": "api",
      "id": "d7-services.resources.definition:Definition",
      "shortName": "Definition",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This module bundles all modules related to drupal definition resource",
      "keywords": "api bundles channel channelconstant d7-services definition drupal module modules object resource resourceconstant resources"
    },
    {
      "section": "api",
      "id": "d7-services.resources.file:File",
      "shortName": "File",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This module bundles all modules related to drupal file resource",
      "keywords": "api bundles channel channelconstant d7-services drupal file module modules object resource resourceconstant resources"
    },
    {
      "section": "api",
      "id": "d7-services.resources.geocoder:Geocoder",
      "shortName": "Geocoder",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This module bundles all modules related to drupal geocoder resource",
      "keywords": "api bundles channel channelconstant d7-services drupal geocoder module modules object resource resourceconstant resources"
    },
    {
      "section": "api",
      "id": "d7-services.resources.menu:Menu",
      "shortName": "Menu",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This module bundles all modules related to drupal menu resource",
      "keywords": "api bundles channel channelconstant d7-services drupal menu module modules object resource resourceconstant resources"
    },
    {
      "section": "api",
      "id": "d7-services.resources.node:Node",
      "shortName": "Node",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This Module bundles all modules related to drupal node resource",
      "keywords": "api bundles channel channelconstant d7-services drupal module modules node object resource resourceconstant resources"
    },
    {
      "section": "api",
      "id": "d7-services.resources.system.channel:SystemChannel",
      "shortName": "SystemChannel",
      "type": "service",
      "moduleName": "d7-services.resources.system",
      "shortDescription": "Notification channel for system resource.",
      "keywords": "$rootscope _scope angular api args arguments automatically basechannel call callback channel channelconstant commons confirm connectconfirmed connectfailed controller d7-services data delvariableconfirmed delvariablefailed destroy event eventbus events failed function getvariableconfirmed getvariablefailed method module mycontroller mymodule notification os pubconnectconfirmed pubconnectfailed pubgetvariableconfirmed publish request requests resource resources scope scopehandler scopes service setvariableconfirmed setvariablefailed specific subconnectconfirmed subconnectfailed subdelvariableconfirmed subdelvariablefailed subgetvariableconfirmed subgetvariablefailed subscribe subscribes subsetvariableconfirmed subsetvariablefailed system systemchannel systemconnectconfirmed systemresource systemresources unsub unsubscribe unsubscribes var"
    },
    {
      "section": "api",
      "id": "d7-services.resources.system.channelConstant:SystemChannelConstant",
      "shortName": "SystemChannelConstant",
      "type": "object",
      "moduleName": "d7-services.resources.system",
      "shortDescription": "Constant for the System channel",
      "keywords": "angular api channel channelconstant class config confirm connect connectconfirmed connectfailed console constant controller d7-services d7-services-resources-system-channelconstant-page d7-services-resources-system-channelconstant-systemchannelconstant-page delvariable delvariableconfirmed delvariablefailed editable event failed getvariable getvariableconfirmed getvariablefailed injectable log module my_event_name mymodule object phase resources setvariable setvariableconfirmed setvariablefailed system systemchannelconstant"
    },
    {
      "section": "api",
      "id": "d7-services.resources.system.resource:SystemResource",
      "shortName": "SystemResource",
      "type": "service",
      "moduleName": "d7-services.resources.system",
      "shortDescription": "This service mirrors the Drupal system resource of the services 3.x module.",
      "keywords": "_default angular api avoid baseresource body callback care case case-sensitivity channelconstant collation commons config configurations confirm connect cors currently d7-services data database default del_variable depends details drupal event fail false function functions get_variable handling http logged lower method mirrors module mymodule names object performing persistent php post problems promise request requests required resource resourceconstant resources return returns serialization service services session set set_variable sets settings source subconnectconfirm successful system systemchannel systemresource true type undefine unsets url user variable variable_"
    },
    {
      "section": "api",
      "id": "d7-services.resources.system.resourceConstant:SystemResourceConstant",
      "shortName": "SystemResourceConstant",
      "type": "object",
      "moduleName": "d7-services.resources.system",
      "shortDescription": "Constant for the System resource",
      "keywords": "actions alias alisa angular api class config connect console constant controller custom d7-services d7-services-resources-system-resourceconstant-page d7-services-resources-system-resourceconstant-systemresourceconstant-page default del_variable drupal editable get_variable injectable log module mymodule object override path phase property provided resource resourceconstant resourcepath resources set subpaths system systemresourceconstant"
    },
    {
      "section": "api",
      "id": "d7-services.resources.system:System",
      "shortName": "System",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This Module bundles all modules related to drupal system resource",
      "keywords": "api bundles channel channelconstant d7-services drupal module modules object resource resourceconstant resources system"
    },
    {
      "section": "api",
      "id": "d7-services.resources.taxonomy_term:TaxonomyTerm",
      "shortName": "TaxonomyTerm",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This Module bundles all modules related to drupal taxonomy_term resource",
      "keywords": "api bundles channel channelconstant d7-services drupal module modules object resource resourceconstant resources taxonomy_term"
    },
    {
      "section": "api",
      "id": "d7-services.resources.taxonomy_vocabulary:TaxonomyVocabulary",
      "shortName": "TaxonomyVocabulary",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This Module bundles all modules related to drupal taxonomy_vocabulary resource",
      "keywords": "api bundles channel channelconstant d7-services drupal module modules object resource resourceconstant resources taxonomy_vocabulary"
    },
    {
      "section": "api",
      "id": "d7-services.resources.user:User",
      "shortName": "User",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This Module bundles all modules related to drupal user resource",
      "keywords": "api bundles channel channelconstant d7-services drupal module modules object resource resourceconstant resources user"
    },
    {
      "section": "api",
      "id": "d7-services.resources.views:Views",
      "shortName": "Views",
      "type": "object",
      "moduleName": "d7-services.resources",
      "shortDescription": "This Module bundles all modules related to drupal views resource",
      "keywords": "api bundles channel channelconstant d7-services drupal module modules object operatorsconstant resource resourceconstant resources views"
    },
    {
      "section": "api",
      "id": "d7-services.resources:Resources",
      "shortName": "Resources",
      "type": "object",
      "moduleName": "d7-services",
      "shortDescription": "This Module bundles all modules related to drupals resources",
      "keywords": "api bundle bundles comment d7-services definition drupals file geocoder menu module modules node object resources system taxonomy_term taxonomy_vocabulary user views"
    },
    {
      "section": "api",
      "id": "d7-services:D7Services",
      "shortName": "D7Services",
      "type": "object",
      "moduleName": "d7-services:D7Services",
      "shortDescription": "This Module bundles all ng-drupal-7-services modules",
      "keywords": "api bundle bundles commons d7-services module modules ng-drupal-7-services object resources"
    }
  ],
  "apis": {
    "api": true
  },
  "__file": "_FAKE_DEST_/js/docs-setup.js",
  "__options": {
    "startPage": "/api",
    "scripts": [
      "js/angular.min.js",
      "js/angular-animate.min.js",
      "js/marked.js"
    ],
    "styles": [],
    "title": "API Documentation",
    "html5Mode": true,
    "editExample": true,
    "navTemplate": false,
    "navContent": "",
    "navTemplateData": {},
    "loadDefaults": {
      "angular": true,
      "angularAnimate": true,
      "marked": true
    }
  },
  "html5Mode": true,
  "editExample": true,
  "startPage": "/api",
  "scripts": [
    "js/angular.min.js",
    "js/angular-animate.min.js",
    "js/marked.js"
  ]
};
